# git.ir Video Downloader
Downloads video files from scattered links throughout a git.ir page.

> Note: Only for freely available video.


## Installing:

```bash
$ pip install gitir_downloader
```

## Usage:

All the files will be downloaded inside a custom folder.

```bash
$ gid <git.ir_url>
```

To create a user defined function, use the `--name` flag.

```bash
$ gid <git.ir_url> --name 'Python Scripting'
```
